package com.hchyun.test.dao;

import java.util.List;

import com.hchyun.test.entity.AssFather;

/**
 * 关联查询父Mapper接口
 *
 * @author hchyun
 * @date 2021-02-10
 */
public interface AssFatherDao {
    /**
     * 查询关联查询父
     *
     * @param id 关联查询父ID
     * @return 关联查询父
     */
    AssFather selectAssFatherById(Long id);

    /**
     * 查询关联查询父列表
     *
     * @param assFather 关联查询父
     * @return 关联查询父集合
     */
    List<AssFather> selectAssFatherList(AssFather assFather);

    /**
     * 新增关联查询父
     *
     * @param assFather 关联查询父
     * @return 结果
     */
    int insertAssFather(AssFather assFather);

    /**
     * 修改关联查询父
     *
     * @param assFather 关联查询父
     * @return 结果
     */
    int updateAssFather(AssFather assFather);

    /**
     * 删除关联查询父
     *
     * @param id 关联查询父ID
     * @return 结果
     */
    int deleteAssFatherById(Long id);

    /**
     * 批量删除关联查询父
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    int deleteAssFatherByIds(Long[] ids);
}
